@@ -42,6 +42,7 @@ impl fmt::Display for MACBFlags {
     }
 }
 
+#[derive(Debug)]
 pub struct ListEntry {
     pub flags: MACBFlags,
     pub line: Arc<Bodyfile3Line>,
@@ -79,9 +80,8 @@ fn insert_timestamp(
     } else if flag.contains(MACBFlags::B) {
         line.get_crtime()
     } else {
-        panic!("no flags set")
+        -1
     };
-    assert_ne!(timestamp, -1);
 
     match entries.get_mut(&timestamp) {
         None => {
@@ -142,11 +142,12 @@ impl BodyfileSorter {
             });
 
             // # we need *some* value in mactimes!
-            if line.get_mtime() == 0
-                && line.get_atime() == 0
-                && line.get_ctime() == 0
-                && line.get_crtime() == 0
+            if line.get_mtime() == -1
+                && line.get_atime() == -1
+                && line.get_ctime() == -1
+                && line.get_crtime() == -1
             {
+                insert_timestamp(&mut entries, MACBFlags::NONE, Arc::clone(&line));
                 continue;
             }
 
